#' @inherit lintr::any_duplicated_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/any_duplicated_linter>.

#' @usage any_duplicated_linter
#' @name any_duplicated_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'any_duplicated_linter',
  function() {
    function() 'any_duplicated'
  },
  env = environment()
)


#' @inherit lintr::any_is_na_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/any_is_na_linter>.

#' @usage any_is_na_linter
#' @name any_is_na_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'any_is_na_linter',
  function() {
    function() 'any_is_na'
  },
  env = environment()
)


#' @inherit lintr::class_equals_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/class_equals_linter>.

#' @usage class_equals_linter
#' @name class_equals_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'class_equals_linter',
  function() {
    function() 'class_equals'
  },
  env = environment()
)


#' @inherit lintr::condition_message_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/condition_message_linter>.

#' @usage condition_message_linter
#' @name condition_message_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'condition_message_linter',
  function() {
    function() 'condition_message'
  },
  env = environment()
)


#' double_assignment

#' @usage double_assignment_linter
#' @name double_assignment_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'double_assignment_linter',
  function() {
    function() 'double_assignment'
  },
  env = environment()
)


#' @inherit lintr::duplicate_argument_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/duplicate_argument_linter>.

#' @usage duplicate_argument_linter
#' @name duplicate_argument_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'duplicate_argument_linter',
  function() {
    function() 'duplicate_argument'
  },
  env = environment()
)


#' empty_assignment

#' @usage empty_assignment_linter
#' @name empty_assignment_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'empty_assignment_linter',
  function() {
    function() 'empty_assignment'
  },
  env = environment()
)


#' equal_assignment

#' @usage equal_assignment_linter
#' @name equal_assignment_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'equal_assignment_linter',
  function() {
    function() 'equal_assignment'
  },
  env = environment()
)


#' @inherit lintr::equals_na_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/equals_na_linter>.

#' @usage equals_na_linter
#' @name equals_na_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'equals_na_linter',
  function() {
    function() 'equals_na'
  },
  env = environment()
)


#' @inherit lintr::expect_comparison_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_comparison_linter>.

#' @usage expect_comparison_linter
#' @name expect_comparison_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_comparison_linter',
  function() {
    function() 'expect_comparison'
  },
  env = environment()
)


#' @inherit lintr::expect_identical_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_identical_linter>.

#' @usage expect_identical_linter
#' @name expect_identical_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_identical_linter',
  function() {
    function() 'expect_identical'
  },
  env = environment()
)


#' @inherit lintr::expect_length_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_length_linter>.

#' @usage expect_length_linter
#' @name expect_length_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_length_linter',
  function() {
    function() 'expect_length'
  },
  env = environment()
)


#' @inherit lintr::expect_named_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_named_linter>.

#' @usage expect_named_linter
#' @name expect_named_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_named_linter',
  function() {
    function() 'expect_named'
  },
  env = environment()
)


#' @inherit lintr::expect_not_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_not_linter>.

#' @usage expect_not_linter
#' @name expect_not_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_not_linter',
  function() {
    function() 'expect_not'
  },
  env = environment()
)


#' @inherit lintr::expect_null_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_null_linter>.

#' @usage expect_null_linter
#' @name expect_null_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_null_linter',
  function() {
    function() 'expect_null'
  },
  env = environment()
)


#' @inherit lintr::expect_s3_class_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_s3_class_linter>.

#' @usage expect_s3_class_linter
#' @name expect_s3_class_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_s3_class_linter',
  function() {
    function() 'expect_s3_class'
  },
  env = environment()
)


#' @inherit lintr::expect_s4_class_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_s4_class_linter>.

#' @usage expect_s4_class_linter
#' @name expect_s4_class_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_s4_class_linter',
  function() {
    function() 'expect_s4_class'
  },
  env = environment()
)


#' @inherit lintr::expect_true_false_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_true_false_linter>.

#' @usage expect_true_false_linter
#' @name expect_true_false_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_true_false_linter',
  function() {
    function() 'expect_true_false'
  },
  env = environment()
)


#' @inherit lintr::expect_type_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/expect_type_linter>.

#' @usage expect_type_linter
#' @name expect_type_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'expect_type_linter',
  function() {
    function() 'expect_type'
  },
  env = environment()
)


#' @inherit lintr::for_loop_index_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/for_loop_index_linter>.

#' @usage for_loop_index_linter
#' @name for_loop_index_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'for_loop_index_linter',
  function() {
    function() 'for_loop_index'
  },
  env = environment()
)


#' @inherit lintr::function_return_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/function_return_linter>.

#' @usage function_return_linter
#' @name function_return_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'function_return_linter',
  function() {
    function() 'function_return'
  },
  env = environment()
)


#' implicit_assignment

#' @usage implicit_assignment_linter
#' @name implicit_assignment_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'implicit_assignment_linter',
  function() {
    function() 'implicit_assignment'
  },
  env = environment()
)


#' @inherit lintr::is_numeric_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/is_numeric_linter>.

#' @usage is_numeric_linter
#' @name is_numeric_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'is_numeric_linter',
  function() {
    function() 'is_numeric'
  },
  env = environment()
)


#' @inherit lintr::length_levels_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/length_levels_linter>.

#' @usage length_levels_linter
#' @name length_levels_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'length_levels_linter',
  function() {
    function() 'length_levels'
  },
  env = environment()
)


#' @inherit lintr::length_test_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/length_test_linter>.

#' @usage length_test_linter
#' @name length_test_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'length_test_linter',
  function() {
    function() 'length_test'
  },
  env = environment()
)


#' @inherit lintr::lengths_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/lengths_linter>.

#' @usage lengths_linter
#' @name lengths_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'lengths_linter',
  function() {
    function() 'lengths'
  },
  env = environment()
)


#' @inherit lintr::library_call_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/library_call_linter>.

#' @usage library_call_linter
#' @name library_call_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'library_call_linter',
  function() {
    function() 'library_call'
  },
  env = environment()
)


#' @inherit lintr::list_comparison_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/list_comparison_linter>.

#' @usage list_comparison_linter
#' @name list_comparison_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'list_comparison_linter',
  function() {
    function() 'list_comparison'
  },
  env = environment()
)


#' @inherit lintr::literal_coercion_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/literal_coercion_linter>.

#' @usage literal_coercion_linter
#' @name literal_coercion_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'literal_coercion_linter',
  function() {
    function() 'literal_coercion'
  },
  env = environment()
)


#' @inherit lintr::matrix_apply_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/matrix_apply_linter>.

#' @usage matrix_apply_linter
#' @name matrix_apply_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'matrix_apply_linter',
  function() {
    function() 'matrix_apply'
  },
  env = environment()
)


#' @inherit lintr::missing_argument_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/missing_argument_linter>.

#' @usage missing_argument_linter
#' @name missing_argument_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'missing_argument_linter',
  function() {
    function() 'missing_argument'
  },
  env = environment()
)


#' @inherit lintr::nested_ifelse_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/nested_ifelse_linter>.

#' @usage nested_ifelse_linter
#' @name nested_ifelse_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'nested_ifelse_linter',
  function() {
    function() 'nested_ifelse'
  },
  env = environment()
)


#' @inherit lintr::numeric_leading_zero_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/numeric_leading_zero_linter>.

#' @usage numeric_leading_zero_linter
#' @name numeric_leading_zero_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'numeric_leading_zero_linter',
  function() {
    function() 'numeric_leading_zero'
  },
  env = environment()
)


#' @inherit lintr::nzchar_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/nzchar_linter>.

#' @usage nzchar_linter
#' @name nzchar_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'nzchar_linter',
  function() {
    function() 'nzchar'
  },
  env = environment()
)


#' @inherit lintr::outer_negation_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/outer_negation_linter>.

#' @usage outer_negation_linter
#' @name outer_negation_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'outer_negation_linter',
  function() {
    function() 'outer_negation'
  },
  env = environment()
)


#' @inherit lintr::package_hooks_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/package_hooks_linter>.

#' @usage package_hooks_linter
#' @name package_hooks_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'package_hooks_linter',
  function() {
    function() 'package_hooks'
  },
  env = environment()
)


#' @inherit lintr::paste_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/paste_linter>.

#' @usage paste_linter
#' @name paste_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'paste_linter',
  function() {
    function() 'paste'
  },
  env = environment()
)


#' @inherit lintr::redundant_equals_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/redundant_equals_linter>.

#' @usage redundant_equals_linter
#' @name redundant_equals_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'redundant_equals_linter',
  function() {
    function() 'redundant_equals'
  },
  env = environment()
)


#' @inherit lintr::redundant_ifelse_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/redundant_ifelse_linter>.

#' @usage redundant_ifelse_linter
#' @name redundant_ifelse_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'redundant_ifelse_linter',
  function() {
    function() 'redundant_ifelse'
  },
  env = environment()
)


#' @inherit lintr::rep_len_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/rep_len_linter>.

#' @usage rep_len_linter
#' @name rep_len_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'rep_len_linter',
  function() {
    function() 'rep_len'
  },
  env = environment()
)


#' right_assignment

#' @usage right_assignment_linter
#' @name right_assignment_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'right_assignment_linter',
  function() {
    function() 'right_assignment'
  },
  env = environment()
)


#' @inherit lintr::sample_int_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/sample_int_linter>.

#' @usage sample_int_linter
#' @name sample_int_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'sample_int_linter',
  function() {
    function() 'sample_int'
  },
  env = environment()
)


#' @inherit lintr::seq_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/seq_linter>.

#' @usage seq_linter
#' @name seq_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'seq_linter',
  function() {
    function() 'seq'
  },
  env = environment()
)


#' @inherit lintr::sort_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/sort_linter>.

#' @usage sort_linter
#' @name sort_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'sort_linter',
  function() {
    function() 'sort'
  },
  env = environment()
)


#' @inherit lintr::stopifnot_all_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/stopifnot_all_linter>.

#' @usage stopifnot_all_linter
#' @name stopifnot_all_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'stopifnot_all_linter',
  function() {
    function() 'stopifnot_all'
  },
  env = environment()
)


#' @inherit lintr::T_and_F_symbol_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/T_and_F_symbol_linter>.

#' @usage T_and_F_symbol_linter
#' @name T_and_F_symbol_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'T_and_F_symbol_linter',
  function() {
    function() 'T_and_F_symbol'
  },
  env = environment()
)


#' @inherit lintr::todo_comment_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/todo_comment_linter>.

#' @usage todo_comment_linter
#' @name todo_comment_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'todo_comment_linter',
  function() {
    function() 'todo_comment'
  },
  env = environment()
)


#' @inherit lintr::undesirable_function_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/undesirable_function_linter>.

#' @usage undesirable_function_linter
#' @name undesirable_function_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'undesirable_function_linter',
  function() {
    function() 'undesirable_function'
  },
  env = environment()
)


#' @inherit lintr::undesirable_operator_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/undesirable_operator_linter>.

#' @usage undesirable_operator_linter
#' @name undesirable_operator_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'undesirable_operator_linter',
  function() {
    function() 'undesirable_operator'
  },
  env = environment()
)


#' @inherit lintr::unnecessary_nesting_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/unnecessary_nesting_linter>.

#' @usage unnecessary_nesting_linter
#' @name unnecessary_nesting_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'unnecessary_nesting_linter',
  function() {
    function() 'unnecessary_nesting'
  },
  env = environment()
)


#' @inherit lintr::vector_logic_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/vector_logic_linter>.

#' @usage vector_logic_linter
#' @name vector_logic_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'vector_logic_linter',
  function() {
    function() 'vector_logic'
  },
  env = environment()
)


#' @inherit lintr::which_grepl_linter title
#' @description
#' See <https://lintr.r-lib.org/reference/which_grepl_linter>.

#' @usage which_grepl_linter
#' @name which_grepl_linter
#' @export
#' @return The name of the linter
NULL
makeActiveBinding(
  'which_grepl_linter',
  function() {
    function() 'which_grepl'
  },
  env = environment()
)
